<h1 align="center">kilroy-server-py-utils</h1>

<div align="center">

utilities for kilroy servers in Python 🔧

[![Tests](https://github.com/kilroybot/kilroy-server-py-utils/actions/workflows/test-multiplatform.yml/badge.svg)](https://github.com/kilroybot/kilroy-server-py-utils/actions/workflows/test-multiplatform.yml)
[![Docs](https://github.com/kilroybot/kilroy-server-py-utils/actions/workflows/docs.yml/badge.svg)](https://github.com/kilroybot/kilroy-server-py-utils/actions/workflows/docs.yml)

</div>

---

TODO

## Installing

Using `pip`:

```sh
pip install kilroy-server-py-utils
```
